==> qtjambi-xmlpatterns-5.15.14-sources.jar: io/qt/xmlpatterns/QXmlResultItems.java <==
package io.qt.xmlpatterns;

import io.qt.*;


/**
 * <p>Iterates through the results of evaluating an XQuery in QXmlQuery</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qxmlresultitems.html">QXmlResultItems</a></p>
 */
public class QXmlResultItems extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlresultitems.html#QXmlResultItems">QXmlResultItems::QXmlResultItems()</a></p>
     */
    public QXmlResultItems(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlResultItems instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlresultitems.html#current">QXmlResultItems::current()const</a></p>
     */
    @QtUninvokable
    public final io.qt.xmlpatterns.@NonNull QXmlItem current(){
        return current_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.xmlpatterns.QXmlItem current_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlresultitems.html#hasError">QXmlResultItems::hasError()const</a></p>
     */
    @QtUninvokable
    public final boolean hasError(){
        return hasError_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasError_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlresultitems.html#next">QXmlResultItems::next()</a></p>
     */
    @QtUninvokable
    public final io.qt.xmlpatterns.@NonNull QXmlItem next(){
        return next_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.xmlpatterns.QXmlItem next_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QXmlResultItems(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-xmlpatterns-5.15.16-sources.jar: io/qt/xmlpatterns/QXmlResultItems.java <==
package io.qt.xmlpatterns;

import io.qt.*;


/**
 * <p>Iterates through the results of evaluating an XQuery in QXmlQuery</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qxmlresultitems.html">QXmlResultItems</a></code></p>
 */
public class QXmlResultItems extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlresultitems.html#QXmlResultItems">QXmlResultItems::<wbr>QXmlResultItems()</a></code></p>
     */
    public QXmlResultItems(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlResultItems instance);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlresultitems.html#current">QXmlResultItems::<wbr>current()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.xmlpatterns.@NonNull QXmlItem current(){
        return current_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.xmlpatterns.QXmlItem current_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlresultitems.html#hasError">QXmlResultItems::<wbr>hasError()const</a></code></p>
     */
    @QtUninvokable
    public final boolean hasError(){
        return hasError_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasError_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlresultitems.html#next">QXmlResultItems::<wbr>next()</a></code></p>
     */
    @QtUninvokable
    public final io.qt.xmlpatterns.@NonNull QXmlItem next(){
        return next_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.xmlpatterns.QXmlItem next_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QXmlResultItems(QPrivateConstructor p) { super(p); } 
    
}
